@@ -72,11 +72,13 @@ class TestModels(unittest.TestCase):
             "traits": {
                 "autonomous_system_number": 1234,
                 "autonomous_system_organization": "AS Organization",
+                "connection_type": "Cable/DSL",
                 "domain": "example.com",
                 "ip_address": "1.2.3.4",
                 "is_anonymous": True,
                 "is_anonymous_proxy": True,
                 "is_anonymous_vpn": True,
+                "is_anycast": True,
                 "is_hosting_provider": True,
                 "is_public_proxy": True,
                 "is_residential_proxy": True,
@@ -193,6 +195,7 @@ class TestModels(unittest.TestCase):
         self.assertIs(model.traits.is_anonymous, True)
         self.assertIs(model.traits.is_anonymous_proxy, True)
         self.assertIs(model.traits.is_anonymous_vpn, True)
+        self.assertIs(model.traits.is_anycast, True)
         self.assertIs(model.traits.is_hosting_provider, True)
         self.assertIs(model.traits.is_public_proxy, True)
         self.assertIs(model.traits.is_residential_proxy, True)
@@ -326,6 +329,11 @@ class TestModels(unittest.TestCase):
             False,
             "traits is_anonymous_proxy returns False by default",
         )
+        self.assertEqual(
+            model.traits.is_anycast,
+            False,
+            "traits is_anycast returns False by default",
+        )
         self.assertEqual(
             model.traits.is_satellite_provider,
             True,
